==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/



define("_HITS","Hits");


define("_BROWSERS","s");
define("_OPERATINGSYS","@~t");
define("_UNKNOWN","");
define("_OTHER","L / ");
define("_MISCSTATS","έp");
define("_REGUSERS","nOϥΪ̡G");
define("_ACTIVEAUTHORS","{檺@̡G");
define("_STORIESPUBLISHED","oɡG");
define("_SACTIVETOPICS","{檺sDDDG");
define("_COMMENTSPOSTED","oNG");
define("_SSPECIALSECT","MG");
define("_ARTICLESSEC","M椺峹G");
define("_LINKSINLINKS","쵲G");
define("_LINKSCAT","쵲OG");
define("_NEWSWAITING","ݵosDG");
define("_NUKEVERSION","PHP-Nuke G");
define("_SEARCHENGINES","jM");
define("_BOTS","Robots/Spiders");
define("_STATS","sέp");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/



define("_HITS","Hits");


define("_BROWSERS","s");
define("_OPERATINGSYS","@~t");
define("_UNKNOWN","");
define("_OTHER","L / ");
define("_MISCSTATS","έp");
define("_REGUSERS","nOϥΪ̡G");
define("_ACTIVEAUTHORS","{檺@̡G");
define("_STORIESPUBLISHED","oɡG");
define("_SACTIVETOPICS","{檺sDDDG");
define("_COMMENTSPOSTED","oNG");
define("_SSPECIALSECT","MG");
define("_ARTICLESSEC","M椺峹G");
define("_LINKSINLINKS","쵲G");
define("_LINKSCAT","쵲OG");
define("_NEWSWAITING","ݵosDG");
define("_NUKEVERSION","PHP-Nuke G");
define("_SEARCHENGINES","jM");
define("_BOTS","Robots/Spiders");
define("_STATS","sέp");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
